@@ -215,13 +215,17 @@ class BingSpider():
             response = self.single_request(keyword, start_page)
         
         # 处理
-
         item_list = self.parser(response, **{"keyword": keyword, "page_num": start_page, "item_num": item_num})
-        return item_list
+        if item_num:
+            return item_list[item_num]
+        else:
+            return item_list
 
 if __name__ == "__main__":
     print("a")
-    # spider = BingSpider()
+    spider = BingSpider()
+    res = spider.search("海南浪淘沙网络科技有限公司")
+    print(res)
     # spider.start_request(["深圳市黑石互娱科技有限公司 企查查"], 0, 1)
     # kwargs = {
     #     "proxies": proxy,
